@@ -44,7 +44,7 @@ class TestWBPaper(unittest.TestCase):
         paper.load_curation_info_from_db(db_name=config["wb_database"]["db_name"], db_user=config["wb_database"]["db_user"],
                                          db_password=config["wb_database"]["db_password"],
                                          db_host=config["wb_database"]["db_host"])
-        self.assertTrue(paper.svm_values["seqchange"] == 'high')
+        self.assertTrue(paper.aut_class_values["seqchange"] == 'high')
 
     @unittest.skipIf(not os.path.exists(os.path.join(os.path.dirname(os.path.abspath(__file__)), "..", "data",
                                                      "local_config", "db.cfg")), "Test DB config file not present")
